<?php
/**
 *	@Class  视频地址解析类
 *	@Author Blueria
 */

Class VideoUrlParser {
	const SUPPORT_LIST = "/(qq\.com|sina\.com\.cn|youku\.com|tudou\.com|56\.com|ku6\.com|sohu\.com)/";	//支持列表
	public $url;
	public $success = 0;	//1:成功 -1:网址不支持 -2:地址有问题
	public $from;
	public $vid;			//视频关键id
	public $iid = '';		//视频ios平台id
	public $img = '';		//视频大缩略图
	public $thumb = '';		//视频小缩略图
	public $code = '';		//土豆特有
	public $lcode = '';		//土豆特有

	function __construct($url) {
		$this->url = $url;
		$this->parse();
	}

	function parse() {
		$lowerurl = strtolower($this->url);
		preg_match(self::SUPPORT_LIST, $lowerurl, $matches);
		if( !$matches ) {
			$this->success = -1;	//网站不被支持
			return false;
		}

		switch( $matches[1] ) {
			case 'qq.com': $this->_parse_qq(); break;
			case 'sina.com.cn': $this->_parse_sina(); break;
			case 'youku.com': $this->_parse_youku(); break;
			case 'tudou.com': $this->_parse_tudou(); break;
			// case 'letv.com': $this->_parse_letv(); break;
			// case 'pptv.com': $this->_parse_pptv(); break;
			case '56.com': $this->_parse_56(); break;
			case 'ku6.com': $this->_parse_ku6(); break;
			case 'sohu.com': $this->_parse_sohu(); break;
		}
	}



	// 1 http://you.video.sina.com.cn/api/sinawebApi/outplayrefer.php/[vid=118051197]_1_P0rmTiIwXmHK+l1lHz2stqkM7KQNt6nknynt71+iJg5RVAuHZorfO4kK4SjeAMpD8GVK/s.swf
	// 1 http://you.video.sina.com.cn/api/sinawebApi/outplayrefer.php/[vid=117853542]_1661729324/s.swf
	
	// 2 http://video.sina.com.cn/[p/news]/w/v/2013-08-13/211162781691.html
	// 2 http://video.sina.com.cn/[p/sports]/o/v/2013-10-29/190563080025.html

	// 5 http://video.sina.com.cn/[vlist/news]/zt/topvideoes20140627/?opsubject_id=top1#134818040
	// 5 http://video.sina.com.cn/[vlist/news]/zt/topvideoes20140626/#134805978

	// 6 http://video.sina.com.cn/[ent]/?opsubject_id=top13[#118024433]
	// 7 http://video.sina.com.cn/[p/ent]/m/c/2013-10-29/192263080403.html			//同6 是同一个视频

	// 8 http://ent.sina.com.cn/[bn/entreport]/[#118059294]							//娱乐播报[当前期]
	// 8 http://ent.sina.com.cn/[bn/entreport]/408/2013/1023/1005.html[#117522644]	//娱乐播报[往期]
	// 8 http://ent.sina.com.cn/f/zymzh/[video/#105316504]

	// 9 http://video.sina.com.cn/[m/ssxtx_64052057].html

	// http://video.sina.com.cn/interface/video_ids/video_ids.php?v=134818040&callback=HTML5_1404059210557
	// http://v.iask.com/v_play_ipad.php?vid=134818409&tags=newsList_web
	private function _parse_sina() {
		$this->from = 'sina';
		//获取vid
		if ( preg_match("#vid=(\d+)#", $this->url, $matches) 						//匹配1
			|| preg_match("@.*#(\d+)$@", $this->url, $matches) )	//匹配5/6/8
		{
			$this->vid = $matches[1];
		} else if ( preg_match("#\/p\/(news|ent|sports)\/.*\.html#", $this->url, $matches)	//匹配2/7
				 || preg_match("#\/m\/\w+_\d+\.html#", $this->url, $matches) ) 		//匹配9
		{
			$videoInfo = $this->http($this->url);	//获取整个网页
			if (false === $videoInfo) {
				$this->success = -2;
				return false;
			}
			preg_match("#\svid:'(\d+)['\|]#", $videoInfo, $vid);
			$this->vid = $vid[1];
		} else {
			$this->success = -2;
			return false;
		}

		//获取iid
		$iidInfo = $this->ihttp("http://video.sina.com.cn/interface/video_ids/video_ids.php?callback=Blueria&v=".$this->vid);
		if (false === $videoInfo) {
			$this->success = -2;
			return false;
		}
		preg_match("#\"ipad_vid\":(\d+)#", $iidInfo, $iid);
		$this->iid = $iid[1];
		
		//获取缩略图
		$imgInfo = $this->http("http://interface.video.sina.com.cn/interface/common/getVideoImage.php?vid=".$this->vid);
		if (false !== $imgInfo) {
			preg_match("#(imgurl=)?(.*)_\d\.jpg#", $imgInfo, $img);
			$this->img = $img[2]."_2.jpg";
			$this->thumb = $img[2]."_1.jpg";
		}

		$this->success = 1;
	}



	// 1 http://static.video.qq.com/TPout.swf?vid=i0012vj54yu&auto=1
	// 2 http://v.qq.com/cover/2/2mc5z2bk9i87ugw.html?vid=s0117xhl5qv
	//   http://v.qq.com/iframe/player.html?vid=a013435r4u7&tiny=0&auto=0
	// 3 http://v.qq.com/cover/0/0114rk3aq7q1kqg/i0012vj54yu.html
	// 4 http://v.qq.com/cover/0/0114rk3aq7q1kqg.html
	// 5 http://film.qq.com/cover/0/0gtuho3asrigan4.html
	// 6 http://v.qq.com/page/f/q/6/f0013twizq6.html
	// 7 http://v.qq.com/boke/page/z/y/q/z0117a3b4yq.html
	private function _parse_qq() {
		$this->from = 'qq';
		//获取vid
		if ( preg_match("#vid=(\w+)#", $this->url, $matches) 						//匹配1/2
			|| preg_match("#cover\/\w\/\w+\/(\w+)\.html#", $this->url, $matches)	//匹配3
			|| preg_match("#page\/.*\/(\w+)\.html#", $this->url, $matches) ) 		//匹配6/7
		{
			$this->vid = $matches[1];
		} else if ( preg_match("#cover\/\w\/\w+\.html#", $this->url) ) {				//匹配4/5
			$videoInfo = $this->http($this->url);	//获取整个网页
			if (false === $videoInfo) {
				$this->success = -2;
				return false;
			}
			preg_match("#\svid:\"(\w+)\"#", $videoInfo, $vid);
			$this->vid = $vid[1];
		} else {
			$this->success = -2;
			return false;
		}

		//不存在iid 跳过

		//获取缩略图
		$cid = @$this->_qq_cid($this->vid);	//这是从Flash里提取的方法(可行 也可以用下面这种获取方式)
		//http://vv.video.qq.com/geturl?otype=json&vid=m00128h36xb&charge=0&callback=qqback
		//http://vv.video.qq.com/geturl?otype=xml&vid=m00128h36xb&charge=0&callback=qqback
		// $videoInfo = $this->http("http://vv.video.qq.com/geturl?otype=json&vid=".$this->vid);
		// preg_match("#video\.store\.qq\.com\/(\d+)\/#", $videoInfo, $cid);
		// $cid = $cid[1];
		$this->img = "http://vpic.video.qq.com/{$cid}/".$this->vid.".png";
		$this->thumb = "http://vpic.video.qq.com/{$cid}/".$this->vid.".jpg";

		$this->success = 1;
	}
	private function _qq_cid($key) {
		$_3 = 4294967296;
		$_5 = 10000 * 10000;
		$_6 = $key;
		$_8 = $_9 = 0;
		while ($_8 < strlen($_6)) {
			$_10 = ord( substr($_6, $_8, 1) );
			$_9 = $_9 * 32 + $_9 + $_10;
			if ($_9 >= $_3) $_9 = fmod($_9, $_3);
			$_8 += 1;
		}
		return fmod($_9, $_5);
		//http://vpic.video.qq.com/60935507/m00128h36xb.png;
		//http://video.store.qq.com/60935507/m00128h36xb.mp4
	}



	// 1 http://player.youku.com/player.php/sid/XNDgzNjE0MDg4/v.swf
	// 2 http://player.youku.com/player.php/Type/Folder/Fid/19963606/Ob/1/sid/XNjMyNzgxNzg0/v.swf

	// 3 http://v.youku.com/v_show/id_XNDgzNjE0MDg4.html
	// 4 http://v.youku.com/v_show/id_XNjMyNzM2NDA4_ev_5.html
	// 5 http://v.youku.com/v_show/id_XMjQxNTE5MTI=.html?f=1690854	//竟然有等于号
	private function _parse_youku() {
		$this->from = 'youku';
		//获取vid
		if ( preg_match("#\/sid\/(\w+\=?)\/#", $this->url, $matches) 					//匹配1/2
			|| preg_match("#\/id\_(\w+\=?)[\_\.]#U", $this->url, $matches) ) {			//匹配3/4/5
			$this->vid = $matches[1];
		} else {
			$this->success = -2;
			return false;
		}

		//不存在iid 跳过

		//获取缩略图
		$this->_youku_preview($this->vid);

		$this->success = 1;
	}
	private function _youku_preview($youku_id) {
		$imgInfo = $this->http("http://v.youku.com/player/getPlayList/VideoIDS/".$youku_id);
		if (false !== $imgInfo) {
			$imgInfo = json_decode($imgInfo);
			$this->img = $imgInfo->data[0]->logo;
			$this->thumb = preg_replace("/com\/1/", 'com/0', $this->img);
		}
	}



	// 1 http://www.tudou.com/programs/view/h__TnYYa9h0/
	//   http://www.tudou.com/programs/view/html5embed.action?type=0&code=h__TnYYa9h0&lcode=
	// 2 http://www.tudou.com/v/h__TnYYa9h0/v.swf
	// 2 http://www.tudou.com/v/h__TnYYa9h0/&resourceId=0_04_02_99&tid=0/v.swf

	// 3 http://www.tudou.com/listplay/ceTuDvFh_C8/Hy7WoC0VtWY.html
	//   http://www.tudou.com/programs/view/html5embed.action?type=1&code=Hy7WoC0VtWY&lcode=ceTuDvFh_C8
	// 4 http://www.tudou.com/l/ceTuDvFh_C8/&iid=173372904/v.swf

	// 5 http://www.tudou.com/albumplay/cSupyRqpB5k.html				//不标准
	//   http://www.tudou.com/programs/view/html5embed.action?type=2&code=BZSt0wkBuyU&lcode=cSupyRqpB5k
	// 6 http://www.tudou.com/a/cSupyRqpB5k/&iid=131562616/v.swf
	// 5 http://www.tudou.com/albumplay/4V_ID3bwAHQ/AkC9VF_Y0FY.html	//标准
	// 6 http://www.tudou.com/a/4V_ID3bwAHQ/&iid=131562659/v.swf
	private function _parse_tudou() {
		$this->from = 'tudou';
		//获取vid
		if ( preg_match("#\/v(iew)?\/([\w\-]+)\/#", $this->url, $matches) ) {				//匹配1/2
			$videoInfo = $this->http("http://www.tudou.com/programs/view/{$matches[2]}/");
			if (false === $videoInfo) {
				$this->success = -2;
				return false;
			}
			preg_match("#,iid:\s?(\d+)#", $videoInfo, $vid);
			$this->vid = $vid[1];
			$this->code = $matches[2];	//h__TnYYa9h0
		} else if ( preg_match("#\/listplay\/([\w\-]+)\/([\w\-]+)#", $this->url, $matches) ) {	//匹配3
			$videoInfo = $this->http($this->url);
			if (false === $videoInfo) {
				$this->success = -2;
				return false;
			}
			preg_match("#,iid:\s?(\d+)#", $videoInfo, $vid);
			$this->vid = $vid[1];
			$this->code = $matches[2];	//Hy7WoC0VtWY
			$this->lcode = $matches[1];	//ceTuDvFh_C8
		} else if ( preg_match("#\/l\/([\w\-]+)\/.*iid=(\d+)#", $this->url, $matches) ) {		//匹配4
			$this->vid = $matches[2];
			$this->lcode = $matches[1];	//ceTuDvFh_C8
			$urlInfo = $this->get_redirection_url($this->url);
			if ( preg_match("/&code=([\w\-]+)/", $urlInfo, $urlInfo) ) {
				$this->code = $urlInfo[1];
			} else {
				$this->success = -2;
				return false;
			}
		} else if ( preg_match("#\/(albumplay)\/([\w\-]+)\/([\w\-]+)#", $this->url, $matches)	//匹配5
				 || preg_match("#\/a\/(\w+)\/.*iid=(\d+)#", $this->url, $matches) ) {		//匹配6
			if ($matches[1] == 'albumplay') {	//如果是网页地址
				$url = $this->url;
				$this->code = $matches[3];	//AkC9VF_Y0FY
				$this->lcode = $matches[2];	//4V_ID3bwAHQ
			} else {							//如果是swf地址
				$urlInfo = $this->get_redirection_url($this->url);		//事实上url中还包含了优酷vid以及缩略图地址
				if ( preg_match("/&code=([\w\-]+)/", $urlInfo, $urlInfo) ) {
					$url = "http://www.tudou.com/albumplay/".$matches[1]."/".$urlInfo[1].".html";
					$this->code = $urlInfo[1];
					$this->lcode = $matches[1];
				} else {
					$this->success = -2;
					return false;
				}
			}
			$videoInfo = $this->http($url);
			if (false === $videoInfo) {
				$this->success = -2;
				return false;
			}
			if ( preg_match("#,vcode:\s'(\w+\=?)'#", $videoInfo, $vid) ) {		//如果检测到优酷的vid
				$this->from = 'youku';	//这是youku的共享视频 比较特别
				$this->vid = $vid[1];
				// preg_match("#,pic:\s?[\"\'](.*)[\"\']#", $videoInfo, $pic);		//顺便获取一下缩略图
			} else if ( preg_match("#iid:\s(\d+)'#", $videoInfo, $vid) ) {
				$this->vid = $vid[1];
			}
		} else {
			$this->success = -2;
			return false;
		}

		//不存在iid 跳过

		//获取缩略图
		if ($this->from == 'tudou') {
			$iid = substr(strval((int)$this->vid + 1000000000), 1, 9);	//0填充到9位
			preg_match_all('#(\d{3})#', $iid, $m_iid);
			$iidEncode = $m_iid[0][0].'/'.$m_iid[0][1].'/'.$m_iid[0][2];
			$this->img = "http://i1.tdimg.com/{$iidEncode}/w.jpg";		//大缩略图
			$this->thumb = "http://i1.tdimg.com/{$iidEncode}/p.jpg";	//小缩略图
		} else {
			$this->_youku_preview($this->vid);
		}

		$this->success = 1;
	}



	// 1 http://www.letv.com/ptv/vplay/2171301.html
	// 2 http://i7.imgs.letv.com/player/swfPlayer.swf?id=2171301&autoplay=0
	// 1 http://www.letv.com/ptv/vplay/20080849.html
	// 2 http://i7.imgs.letv.com/player/swfPlayer.swf?id=20080849&autoplay=0
	private function _parse_letv() {
		$this->from = 'letv';
		if ( preg_match("#\/vplay\/(\d+)#", $this->url, $matches) 					//匹配1
			|| preg_match("#\/player\/.*id=(\d+)#", $this->url, $matches) ) {		//匹配2
			$this->vid = $matches[1];
		} else {
			$this->success = -2;
			return false;
		}
		$this->success = 1;
	}



	// 1 http://v.pptv.com/show/K08cmkUFe7kcmgI.html
	// 2 http://player.pptv.com/v/K08cmkUFe7kcmgI.swf
	private function _parse_pptv() {
		$this->from = 'pptv';
		//获取vid
		if ( preg_match("#pptv\.com\/(show|v)\/(\w+)\.#", $this->url, $matches) ) {		//匹配1/2
			$this->vid = $matches[2];
		} else {
			$this->success = -2;
			return false;
		}

		//获取iid
		$videoInfo = $this->http("http://v.pptv.com/show/".$this->vid.".html");	//获取整个网页
		if (false === $videoInfo) {
			$this->success = -2;
			return false;
		}
		if ( preg_match("#\"id\":(\d+),#U", $videoInfo, $vid) ){
			$this->iid = $vid[1];
		} else {	//通过手机端获取
			$videoInfo = $this->ihttp("http://m.pptv.com/show/".$this->vid.".html");
			if (false === $videoInfo) {
				$this->success = -2;
				return false;
			}
			if ( preg_match("#\"channel_id\":(\d+),#U", $videoInfo, $vid) ) $this->iid = $vid[1];
		}

		//获取缩略图
		$this->img = "http://s1.pplive.cn/v/cap/".$this->iid."/w640.jpg";
		// $this->thumb = "http://s1.pplive.cn/v/cap/".$this->iid."/h160.jpg";
		$this->thumb = "http://s1.pplive.cn/v/cap/".$this->iid."/h120.jpg";

		$this->success = 1;
	}



	// 1 http://www.56.com/u30/v_MTE3OTExOTIz.html
	// 2 http://player.56.com/v_MTE3OTExOTIz.swf
	// 3 http://www.56.com/w35/play_album-aid-10045454_vid-MTE2MzM5MzQ0.html
	// 3 http://www.56.com/w55/play_album-aid-9942946_vid-NzA3NTI2Mzk.html
	private function _parse_56() {
		$this->from = '56';
		//获取vid
		if ( preg_match("#v\_(\w+)#", $this->url, $matches)
			|| preg_match("#\_vid\-(\w+)#", $this->url, $matches) ) {
			$this->vid = $matches[1];
		} else {
			$this->success = -2;
			return false;
		}

		//不存在iid 跳过

		//获取缩略图
		$videoInfo = $this->http("http://vxml.56.com/json/".$this->vid."/?src=out");
		if (false !== $videoInfo) {
			$videoInfo = json_decode($videoInfo);
			$this->img = $videoInfo->info->bimg;
			$this->thumb = $videoInfo->info->img;
		}

		$this->success = 1;
	}



	// 1 http://v.ku6.com/show/of3dRU6p5sCgIgPMr7a1rQ...html?hpsrc=1_24_1_1_0
	// 2 http://player.ku6.com/refer/of3dRU6p5sCgIgPMr7a1rQ../v.swf

	// 3 http://v.ku6.com/special/show_6604091/HaRzz7unrra6pQHwXYBWOA...html?csrc=7_59_1
	// 2 http://player.ku6.com/refer/HaRzz7unrra6pQHwXYBWOA../v.swf

	// 4 http://topic.ku6.com/show-99381-N38RLAKozdYK_J83WXW4nQ...html?st=5_4_5_1
	// 2 http://player.ku6.com/refer/N38RLAKozdYK_J83WXW4nQ../v.swf

	// http://v.ku6.com/fetchVideo4Player/9G0yzmMQX20OGVuCRWkRzw...html
	// http://v.ku6.com/fetch.htm?t=getVideo4Player&vid=9G0yzmMQX20OGVuCRWkRzw..&stype=mp4
	private function _parse_ku6() {
		$this->from = 'ku6';
		//获取vid
		if ( preg_match("#(?:refer|show)\/([\w\-\.]+)[\.\/]#", $this->url, $matches)			//匹配1/2
			|| preg_match("#special\/show_(?:\d+)\/([\w\-\.]+)\.html#", $this->url, $matches)	//匹配3
			|| preg_match("#\/show\-(?:\d+)\-([\w\-\.]+)\.html#", $this->url, $matches) ) {		//匹配4
			$this->vid = $matches[1];
		} else {
			$this->success = -2;
			return false;
		}

		//不存在iid 跳过

		//获取缩略图
		$videoInfo = $this->http("http://v.ku6.com/fetchVideo4Player/".$this->vid.".html");
		if (false !== $videoInfo) {
			$videoInfo = json_decode($videoInfo);
			$this->img = $videoInfo->data->bigpicpath;
			$this->thumb = $videoInfo->data->picpath;
		}

		$this->success = 1;
	}



	// 1 http://tv.sohu.com/20140623/n401198673.shtml
	// 2 http://share.vrs.sohu.com/1839113/v.swf
	
	// 3 http://my.tv.sohu.com/us/53468100/70955338.shtml?pvid=3f1cc80360d8da18
	// 4 http://share.vrs.sohu.com/my/v.swf&id=70955338&autoplay=false&topBar=1&from=page
	// 3 http://my.tv.sohu.com/pl/6899542/70435247.shtml
	// 4 http://share.vrs.sohu.com/my/v.swf&id=70435247&autoplay=false&topBar=1&from=page
	// 5 http://my.tv.sohu.com/pl/5824396.shtml	(这种可以忽略)
	private function _parse_sohu() {
		$this->from = 'sohu';
		//获取vid
		$img = '';
		if ( preg_match("#\/\/tv\.sohu\.com.*html#", $this->url, $matches) ) {				//匹配1
			$videoInfo = $this->http($this->url);
			if (false === $videoInfo) {
				$this->success = -2;
				return false;
			}
			preg_match("#\svid\s?=\s?\"(\d+)\"#", $videoInfo, $vid);
			preg_match("#\scover\s?=\s?\"(.*)\"#", $videoInfo, $pic);	//顺便获取缩略图
			$this->vid = $vid[1];
			$img = $pic[1];
		} elseif ( preg_match("#share\.vrs\.sohu\.com\/(\d+)#", $this->url, $matches) ) {	//匹配2
			$this->vid = $matches[1];
			$videoInfo = $this->http('http://hot.vrs.sohu.com/vrs_flash.action?vid='.$this->vid);
			if (false !== $videoInfo) {
				$videoInfo = json_decode($videoInfo);
				$img = $videoInfo->data->coverImg;
			}
		} elseif ( preg_match("#\/\/my\.tv\.sohu\.com\/(?:us|pl)\/(?:\d+)\/(\d+)\.shtml#", $this->url, $matches)	//匹配3
				|| preg_match("#\/my\/v\.swf.*id=(\d+)#", $this->url, $matches) ) {									//匹配4
			$this->from = 'sohu-my';	//标记为[搜狐视频空间]
			$this->vid = $matches[1];
			$videoInfo = $this->http('http://my.tv.sohu.com/play/videonew.do?vid='.$this->vid);
			if (false !== $videoInfo) {
				preg_match("#\"coverImg\":\"(.*)\"#U", $videoInfo, $pic);		//直接匹配 不使用json解析
				$img = $pic[1];
			}
		} else {
			$this->success = -2;
			return false;
		}

		//获取缩略图
		if ( preg_match("@\/vrs@i", $img) ) {	//http://photocdn.sohu.com/20130315/vrs765629.jpg
			$this->img = preg_replace("/vrsb?/i", "vrs", $img);
			$this->thumb = preg_replace("/vrsb?/i", "vrsb", $img);
		} elseif ( preg_match("/_S_[sb]/i", $img) ) {	//http://photocdn.sohu.com/20130819/888f94f0-f7d5-4cc0-b917-4e95a79342a4_1282293_S_b.jpg
			$this->img = preg_replace("#_S_[bs]\.#i", "_S_b.", $img);
			$this->thumb = preg_replace("#_S_[bs]\.#i", "_S_s.", $img);
		} elseif ( !empty($img) ) {	//http://223.img.pp.sohu.com.cn/p223/2014/6/19/9/13/6_14782c5dcfag201SysCutcloud_70633888_7_0b.jpg
			$this->img  = preg_replace("#b?\.(jpg|gif|png)$#i", "b.\\1", $img);
			$this->thumb = preg_replace("#b?\.(jpg|gif|png)$#i", ".\\1", $img);
		}

		$this->success = 1;
	}



	//http请求
	public function http($url) {
		$http = new WP_Http();
		$info = $http->request($url);
		if (200 == @$info['response']['code']) {
			return $info['body'];
		} else {
			return false;
		}
	}

	//模拟iphone请求
	public function ihttp($url) {
		$http = new WP_Http();
		$info = $http->request($url, array( 'headers' => $this->headers('Mozilla/5.0 (iPhone; CPU iPhone OS 7_0_3 like Mac OS X) AppleWebKit/537.51.1 (KHTML, like Gecko) Version/7.0 Mobile/11B508 Safari/9537.53') ));
		if (200 == @$info['response']['code']) {
			return $info['body'];
		} else {
			return false;
		}
	}

	//获取重定向地址
	public function get_redirection_url($url) {
		$http = new WP_Http();
		$info = $http->request($url, array('redirection' => 0));
		if (302 == @$info['response']['code']) {
			return $info['headers']['location'];
		} else {
			return false;
		}
	}

	//头信息
	private function headers($ua = null) {
		$ip = $_SERVER['REMOTE_ADDR'];	//访问者ip
		if ($ua == null) $ua = 'Mozilla/5.0 (Windows NT 5.1; rv:30.0) Gecko/20100101 Firefox/30.0';
		$headers = array(
			'X-Forward-For' => $ip,
			'X-Forwarded-For' => $ip,
			'Client-ip' => $ip,
			'User-Agent' => $ua
		);
		return $headers;
	}
}
?>