<?php
/*
 *	Template Name: 投稿页
 */
if ( !defined('ABSPATH') ) {
	header('HTTP/1.0 403 Forbidden');
	exit();
}

$tougao_options = get_option('tougao_options', blueria_get_option('tougao_options'));

//免审权限
function can_publish() {
	return ( current_user_can('tougao_mianshen') || current_user_can('publish_posts') );
}


if ( is_user_logged_in() && !empty($_POST['title']) && !empty($_POST['tags']) && !empty($_POST['code']) ) {
	//验证码检测
	if ( $_SESSION['code'] != strtolower(trim($_POST['code'])) ) {
		urlStatus(false, 1);	//验证码错误
	}

	//验证nonce
	if ( !isset($_POST['blueria_nonce']) || !wp_verify_nonce($_POST['blueria_nonce'], 'blueria') ) {
		urlStatus(false, 2);	//nonce非法
	}

	//验证两次投稿时间差
	if ( !can_publish() ) {
		$cur_user_id = get_current_user_id();
		$user_last_post = $wpdb->get_var("SELECT `post_date` FROM `$wpdb->posts` WHERE `post_author` = {$cur_user_id} ORDER BY `post_date` DESC LIMIT 1");
		if ( $user_last_post && current_time('timestamp') - strtotime($user_last_post) < 120 ) {
			urlStatus(false, 3);	//两次投稿时间小于120秒 投稿太频繁
		}
	}

	//如果禁止图片上传功能 却有上传数据
	if ( $tougao_options['no_uploadimg'] == 'on' && $_FILES['upload_image']['size'] && !wp_is_mobile() ) wp_die("非法操作，本站暂时不允许上传图片！");

	//标题
	$title =  isset( $_POST['title'] ) ? trim(htmlspecialchars($_POST['title'], ENT_QUOTES)) : '';
	if ( empty($title) ) wp_die("非法操作，没有标题！");

	//标签
	if ( !isset($_POST['tags']) ) wp_die("非法操作，没有标签！");
	$tags = (array) $_POST['tags'];

	//分类
	if ( isset($_POST['cats']) ) {
		$cats = (array) $_POST['cats'];
		if ( @$tougao_options['cat_multiselect'] == 'on' && count($cats) > 3 ) {
			wp_die("非法操作，分类最多选3个！");	//多选:最多选3个
		} elseif ( !@$tougao_options['cat_multiselect'] && count($cats) != 1 ) {
			wp_die("非法操作，分类只能单选！");	//只能单选
		}
		foreach ($cats as $cat) {
			if ( !is_numeric($cat) || !in_array($cat, (array)$tougao_options['cats']) ) wp_die("非法操作，分类有误！");
		}
		$cats = array_map('intval', $cats);	//id为整型
	}

	//专题
	if ( isset($_POST['topics']) ) {
		$topics = (array) $_POST['topics'];
		if ( count($topics) != 1 ) wp_die("非法操作，专题有误！");	//只能单选
		foreach ($topics as $topic) {
			if ( !is_numeric($topic) || !in_array($topic, (array)$tougao_options['topics']) ) wp_die("非法操作，专题有误！");
		}
		$topics = array_map('intval', $topics);	//id为整型
	}
	

	$content = isset( $_POST['content'] ) ? trim($_POST['content']) : '';
	$vdo_url = isset( $_POST['video_url'] ) ? trim(htmlspecialchars($_POST['video_url'], ENT_QUOTES)) : '';
	$img_url = isset( $_POST['image_url'] ) ? trim(htmlspecialchars($_POST['image_url'], ENT_QUOTES)) : '';

	if ( !empty($content) ) {
		$content = htmlspecialchars(strip_tags($content), ENT_QUOTES);
		if ( mb_strlen($content) > 320 ) $content = mb_substr($content, 0, 320, 'UTF-8');	//内容超出
	}
	
	//如果视频地址/图片地址/图片上传数据/内容都没有
	if ( empty($content) && empty($vdo_url) && empty($img_url) && !$_FILES['upload_image']['size'] ) {
		urlStatus(false, 4);	//无实质内容
	} 

	elseif ( !empty($img_url) ) {
		if ( !wp_http_validate_url($img_url) ) wp_die("警告，网络图片地址无效！");
		$shortcode = blueria_img_handler($img_url);
		if ( has_shortcode($shortcode, 'bimage') ) {
			$content .= "\n\n".$shortcode;
		} else {
			wp_die("处理图片时，发生了一个错误（{$shortcode}）");
		}
	} 

	elseif ( !empty($vdo_url) ) {
		if ( !wp_http_validate_url($vdo_url) ) wp_die("警告，视频地址无效！");
		$shortcode = blueria_parse_video_info($vdo_url);
		if ($shortcode == -1) wp_die("你添加的视频地址暂不支持，请对照投稿页面下方的支持列表，如有疑问请联系本站管理员！");
		if ($shortcode == -2) wp_die("视频解析出错，请报告给本站管理员！");
		$content .= "\n\n".$shortcode;
	} 

	elseif ( $_FILES['upload_image']['size'] > 0 ) {
		if ( !function_exists('media_handle_upload') ) {
			require_once (ABSPATH . '/wp-admin/includes/media.php');
			require_once (ABSPATH . '/wp-admin/includes/file.php');
			require_once (ABSPATH . '/wp-admin/includes/image.php');
		}
		$attachment_Id = media_handle_upload('upload_image', 0);		//这里的post_ID为0
		if ( !is_wp_error($attachment_Id) && wp_attachment_is_image($attachment_Id) ) {
			$img_url = wp_get_attachment_url( $attachment_Id );
			$shortcode = blueria_img_handler( $img_url, $attachment_Id );
			if ( has_shortcode($shortcode, 'bimage') ) {
				$content .= "\n\n".$shortcode;
			} else {
				wp_die("处理图片时，发生了一个错误（{$shortcode}）");
			}
		} else {
			wp_delete_attachment($attachment_Id);
			wp_die("你上传的这个文件有误！");
		}
	}

	//是否需要审核
	$post_status = 'pending';	//publish
	if ( can_publish() ) {
		$post_status = 'publish';
	}

	$tougao_post = array(
		'post_title' => $title,
		'post_content' => $content,
		'post_author' => $cur_user_id,
		'post_status' => $post_status,
		'tags_input' => $tags,
		'tax_input' => array('topic' => $topics)
	);
	$post_ID = wp_insert_post( $tougao_post );

	if ( $post_ID ) {	//失败是0 成功是id
		if ( $attachment_Id ) wp_update_post( array('ID' => $attachment_Id, 'post_parent' => $post_ID) );	//更新附属文章
		urlStatus(true, $post_status);	//投稿成功
	} else {
		urlStatus(false, 0);			//投稿失败
	}
}



get_header(); ?>


<link rel="stylesheet" href="<?php bloginfo('template_url');?>/ui/tougao.css" media="screen" />

<div class="container public"><div class="inner">

<div class="block page_block tougao_block clearfix">
	<h1 class="title"><?php the_title(); ?></h1>
	<div class="main">
		<?php if ( @$_REQUEST['error'] == '0' ) : ?>
			<div class="Info"><span class="title">Oops！！！</span>发生了一个错误导致投稿失败！<a href="<?php echo remove_query_arg('error', $_SERVER["REQUEST_URI"]); ?>">重新投稿</a></div>
		<?php elseif ( @$_REQUEST['success'] == 'pending' ) : ?>
			<div class="Success"><span class="title">投稿成功！！！</span>恭喜您，投稿成功，您的投稿正在等待审核……</div>
		<?php elseif ( @$_REQUEST['success'] == 'publish' ) : ?>
			<div class="Success"><span class="title">投稿成功！！！</span>恭喜您，投稿成功，您的投稿已发布，去首页看看吧！</div>
		<?php elseif ( @$_REQUEST['error'] == '1' ) : ?>
			<div class="Error">验证码错误！<a href="<?php echo remove_query_arg('error', $_SERVER["REQUEST_URI"]); ?>">重新投稿</a></div>
		<?php elseif ( @$_REQUEST['error'] == '2' ) : ?>
			<div class="Error">非法操作！</div>
		<?php elseif ( @$_REQUEST['error'] == '3' ) : ?>
			<div class="Info">投稿太频繁，浏览一会儿网页，放松一下再回来！</div>
		<?php elseif ( @$_REQUEST['error'] == '4' ) : ?>
			<div class="Info">如果你没有添加任何视频或图片，那么投稿内容是不能留空的！<a href="<?php echo remove_query_arg('error', $_SERVER["REQUEST_URI"]); ?>">重新投稿</a></div>
		<?php elseif ( is_user_logged_in() ) : ?>
		<form method="post" action="" enctype="multipart/form-data">
			<div class="inside">
				<label for="title">标题</label>
				<input type="text" name="title" id="title" value="" maxlength="50" placeholder="输入一个简洁的标题 5-50字之间" />
			</div>
			<div class="inside media">
				<label for="content">内容</label>
				<?php if ( !wp_is_mobile() ) : ?><span class="video_btn"><i class="i-film"></i>添加视频</span><span class="imgurl_btn"><i class="i-image"></i>添加网络图片</span><?php endif; ?><?php if ( !@$tougao_options['no_uploadimg'] || wp_is_mobile() ) : ?><span class='imgupload_btn'><div><i class="i-image"></i>添加本地图片</div><input name="upload_image" id='upload_image' type="file" size='1'></span><?php endif; ?>
				<i class="i-times-circle close" title="关闭 插入其他媒体"></i>
				<textarea name="content" id="content" rows="5" placeholder="在这里输入你要分享的内容 最多300字 超出部分会被自动删除"></textarea>
			</div>

			<?php if ( $tougao_options['tags'] ) : ?>
			<div class="inside">
				<label for="tags">贴上标签</label>
				<div class="box"><?php
					$tags = explode(",", $tougao_options['tags']);
					foreach ($tags as $tag) {
						echo "<span class='term tag' data-type='tag' data-value='{$tag}'><i class='i-tag'></i>{$tag}<em></em></span>";
					}
				?><span class="add_tag"><input type="text" value="" placeholder="自定义标签" /><em title="点此添加自定义的标签">+</em></span></div>
			</div>
			<?php endif; ?>

			<?php if ( @$tougao_options['cats'] ) : ?>
			<div class="inside">
				<label for="cats">选择分类</label>
				<div class='box'><?php
					foreach ($tougao_options['cats'] as $tid) {
						$cat = get_term_by('id', $tid, 'category');
						if ( isset($cat) )
							echo "<span class='term' data-type='cat' data-value='{$tid}'><i class='i-folder'></i>{$cat->name}<em></em></span>";
					}
				?></div>
			</div>
			<?php endif; ?>

			<?php if ( can_publish() && $tougao_options['topics'] ) : ?>
			<div class="inside">
				<label for="topics">选择专题</label>
				<div class='box'><?php
					foreach ($tougao_options['topics'] as $tid) {
						$topic = get_term_by('id', $tid, 'topic');
						if ( isset($topic) )
							echo "<span class='term' data-type='topic' data-value='{$tid}'><i class='i-bookmark'></i>{$topic->name}<em></em></span>";
					}
				?></div>
			</div>
			<?php endif; ?>

			<div class="submitbox">
				<?php wp_nonce_field('blueria', 'blueria_nonce', false); ?>
				<label>
					<img class='code' src="<?php bloginfo('template_url');?>/code.php" title="验证码看不清 点此刷新" onclick="javascript:this.src='<?php bloginfo('template_url');?>/code.php?r='+Math.random();" />
					<input type="text" name="code" id="code" maxlength="4" onkeyup="value=value.replace(/[^\w]/ig, '')" autocomplete="off" placeholder="输入验证码" />
					<img  class='spinner' src="<?php echo admin_url('images/spinner.gif'); ?>" alt="" />
				</label>
				<button type="submit" class="submit disabled"><i class="i-check-circle"></i>提交投稿</button>
			</div>
		</form>
		<?php else : ?>
			<div class="Info"><span class="title">登陆提示！</span>只有登录后才能进行投稿，请点击右上角的登录按钮进行快捷登陆！</div>
		<?php endif; ?>
	</div>
</div>

<div class="block page_block clearfix">
	<h3 class="title">发布规则</h3>
	<ol class="rule">
		<li>标题很重要，请填写<b>描述性的</b>标题，而不是短语如"哈哈"，"快来看"，或"支持"等等。</li>
		<li>添加图片时，图片<b>宽度≥500像素</b>最为适宜。(图片上传限制大小为：<?php echo ini_get('upload_max_filesize'); ?>)</li>
		<li>添加视频时，请参考下方的<b>视频格式说明</b>，不符合说明的将无法显示。</li>
		<li>不得发布露点、暴力、毁谤、非法的内容，请自觉维护网站良好风气。</li>
		<li>转载请注明出处。</li>
	</ol>
</div>

<div class="block page_block clearfix">
	<h3 class="title">支持的视频网站及其格式</h3>
	<table width="100%">
		<tr><th>支持的视频网站</th><th>对应的格式/特征</th></tr>
		<tr><td>优酷网<br />(youku.com)</td><td>
			http://v.youku.com/v_show/id_XNDgzNjE0MDg4.html<br />
			http://player.youku.com/player.php/sid/XNDgzNjE0MDg4/v.swf
		</td></tr>
		<tr><td>土豆网<br />(tudou.com)</td><td>
			http://www.tudou.com/programs/view/h__TnYYa9h0/<br />
			http://www.tudou.com/v/h__TnYYa9h0/v.swf<br />
			http://www.tudou.com/listplay/ceTuDvFh_C8/Hy7WoC0VtWY.html<br />
			http://www.tudou.com/l/ceTuDvFh_C8/&iid=173372904/v.swf<br />
			http://www.tudou.com/albumplay/4V_ID3bwAHQ/AkC9VF_Y0FY.html<br />
			http://www.tudou.com/a/4V_ID3bwAHQ/&iid=131562659/v.swf
		</td></tr>
		<tr><td>56网<br />(56.com)</td><td>
			http://www.56.com/u30/v_MTE3OTExOTIz.html<br />
			http://player.56.com/v_MTE3OTExOTIz.swf<br />
			http://www.56.com/w35/play_album-aid-10045454_vid-MTE2MzM5MzQ0.html
		</td></tr>
		<tr><td>QQ视频<br />(v.qq.com)</td><td>
			http://static.video.qq.com/TPout.swf?vid=i0012vj54yu&auto=1<br />
			http://v.qq.com/cover/2/2mc5z2bk9i87ugw.html?vid=s0117xhl5qv<br />
			http://v.qq.com/cover/0/0114rk3aq7q1kqg/i0012vj54yu.html<br />
			http://v.qq.com/cover/0/0114rk3aq7q1kqg.html<br />
			http://film.qq.com/cover/0/0gtuho3asrigan4.html<br />
			http://v.qq.com/page/f/q/6/f0013twizq6.html<br />
			http://v.qq.com/boke/page/z/y/q/z0117a3b4yq.html
		</td></tr>
		<tr><td>新浪视频<br />(video.sina.com.cn)</td><td>
			http://you.video.sina.com.cn/api/sinawebApi/outplayrefer.php/vid=117853542_1661729324/s.swf<br />
			http://video.sina.com.cn/p/news/w/v/2013-08-13/211162781691.html<br />
			http://video.sina.com.cn/p/sports/o/v/2013-10-29/190563080025.html<br />
			http://video.sina.com.cn/vlist/news/zt/topvideoes20140626/#134805978<br />
			http://video.sina.com.cn/ent/?opsubject_id=top13#118024433<br />
			http://video.sina.com.cn/p/ent/m/c/2013-10-29/192263080403.html<br />
			http://ent.sina.com.cn/bn/entreport/#118059294<br />
			http://video.sina.com.cn/m/ssxtx_64052057.html
		</td></tr>
		<tr><td>搜狐视频<br />(tv.sohu.com)</td><td>
			http://tv.sohu.com/20140623/n401198673.shtml<br />
			http://share.vrs.sohu.com/1839113/v.swf<br />
			http://my.tv.sohu.com/us/53468100/70955338.shtml?pvid=3f1cc80360d8da18<br />
			http://share.vrs.sohu.com/my/v.swf&id=70955338
		</td></tr>
		<!-- <tr><td>PPTV聚力<br />(pptv.com)</td><td>
			http://v.pptv.com/show/K08cmkUFe7kcmgI.html<br />
			http://player.pptv.com/v/K08cmkUFe7kcmgI.swf
		</td></tr> -->
		<tr><td>酷6网<br />(ku6.com)</td><td>
			http://v.ku6.com/show/of3dRU6p5sCgIgPMr7a1rQ...html<br />
			http://player.ku6.com/refer/of3dRU6p5sCgIgPMr7a1rQ../v.swf<br />
			http://v.ku6.com/special/show_6604091/HaRzz7unrra6pQHwXYBWOA...html<br />
			http://topic.ku6.com/show-99381-N38RLAKozdYK_J83WXW4nQ...html
		</td></tr>
	</table>
</div>

</div></div>

<script type="text/javascript" src="<?php bloginfo('template_url');?>/js/jquery.placeholder.1.3.min.js"></script>
<script>
	jQuery(function($){
		$.Placeholder.init();
		$("#title").attr("max", 100).inputlimiter();
		$("#content").attr("max", 600).inputlimiter();

		//媒体按钮点击
		$(".media > span").click(function(){
			var self = $(this);
			self.siblings("span").hide();
			self.siblings(".close").show();
			if ( self.hasClass('video_btn') ) {
				if ( self.data('inited') === undefined ) {
					$('<input type="text" name="video_url" placeholder="在此输入视频地址" />').insertAfter(self).focus();
				} else {
					self.next('input').focus();
				}
			} else if ( self.hasClass('imgurl_btn') ) {
				if ( self.data('inited') === undefined ) {
					$('<input type="text" name="image_url" placeholder="在此输入网络图片地址" />').insertAfter(self).focus();
				} else {
					self.next('input').focus();
				}
			} else if ( self.hasClass('imgupload_btn') ) {
				if ( self.data('inited') === undefined ) self.after('<input type="text" disabled="disabled" />');
			}
			self.data('inited', 1);
		});
		//重新插入其他媒体按钮
		$(".media .close").click(function(){
			var self = $(this);
			self.prevAll('span').removeData('inited').show();
			self.prevAll('input').remove();
			self.hide();
		});
		//上传控件发生变化
		$("#upload_image").change(function(){
			$(".imgupload_btn").next("input").val( '本地图片已选择：'+$(this).val() );
		});

		function singleSelect() {
			var self = $(this);
			var value = self.attr('data-value');
			var type = self.attr('data-type');
			if ( !self.hasClass("selected") ) {
				self.siblings(".term").removeClass("selected");	//只能单选
				self.siblings("input").remove();				//移除所以同辈input
				self.addClass("selected");
				self.after("<input name='"+type+"s[]' type='hidden' value='"+value+"' />");
			} else {
				self.removeClass("selected");
				self.next('input').remove();
			}
		}
		function multiSelect() {
			var self = $(this);
			var value = self.attr('data-value');
			var type = self.attr('data-type');
			var parent = self.parent();
			if ( parent.data('selected') === undefined ) parent.data('selected', 0);
			if ( !self.hasClass("selected") ) {
				if ( parent.data('selected') >= 3 ) {
					alert("分类最多选择3个！");
					return;
				} else {
					self.addClass("selected");
					self.after("<input name='"+type+"s[]' type='hidden' value='"+value+"' />");
					parent.data('selected', parent.data('selected')+1);
				}
			} else {
				self.removeClass("selected");
				self.next('input').remove();
				parent.data('selected', parent.data('selected')-1);
			}
		}

		//专题选择(单选)
		$("span[data-type='topic']").click(singleSelect);

		//分类选择(单选/多选)
		<?php if ( @$tougao_options['cat_multiselect'] == 'on' ) : ?>
		$("span[data-type='cat']").click(multiSelect);
		<?php else: ?>
		$("span[data-type='cat']").click(singleSelect);
		<?php endif; ?>

		//标签选择(多选)
		$(document).on('click', '.tag', function(){
			var self = $(this);
			var value = self.attr('data-value');
			var type = self.attr('data-type');
			if ( !self.hasClass("selected") ) {
				if ( self.siblings('.selected').length >= 5 ) {
					alert('抱歉，最多可以贴上5个标签！');
					return;
				}
				self.addClass("selected");
				self.after("<input name='"+type+"s[]' type='hidden' value='"+value+"' />");
			} else {
				self.removeClass("selected");
				self.next('input').remove();
			}
		});
		//添加自定义标签
		$(".add_tag em").click(function(){
			var self = $(this);
			var new_tag = self.prev('input').val();
			new_tag = $.trim( new_tag );
			if ( '' == new_tag || '自定义标签' == new_tag ) {
				self.prev('input').val('').focus();
				return;
			}
			if ( !isNaN(new_tag) ) {
				alert('请填写有意义的标签，谢谢！');
				self.prev('input').val('').focus();
				return;
			}
			var leng = new_tag.replace(/[^\u0000-\u00ff]/g, "**").length;
			if ( leng > 10 ) {
				alert('抱歉，标签名最多为5个汉字！');
				return;
			}
			if ( self.parent().prevAll('.selected').length >= 5 ) {
				alert('抱歉，最多可以贴上5个标签！');
				return;
			}
			var existed = false;
			self.parent().prevAll().each(function(){
				if ( $(this).attr('data-value') == new_tag ) {
					existed = true;
					self.prev('input').val('');
					if ( ! $(this).hasClass('selected') ) $(this).click();
					return false;
				}
			});
			if ( !existed ) {
				self.parent().before("<span class='term tag selected' data-type='tag' data-value='"+new_tag+"'><i class='i-tag'></i>"+new_tag+"<em></em></span><input name='tags[]' type='hidden' value='"+new_tag+"' />");
				self.prev('input').val('');
			}
		});
		//防止回车提交
		$("form").keypress(function(e){
			if (e.keyCode == '13' && e.target.type != 'textarea') return false;	//禁止回车提交
			return true;
		});
		//自定义标签输入框内回车 触发添加按钮
		$(".add_tag input").bind('keyup', function(e){
			if (e.keyCode == '13') {
				$(this).next('em').click();	//触发添加按钮点击
				return false;
			}
		});

		$("#code").bind('propertychange blur keyup input', function(){
			var self = $(this);
			var code = $.trim( self.val() );
			if ( code == '输入验证码' || code.length != 4 ) {
				// setTimeout(function(){
				// 	self.focus();
				// }, 100);
				return;
			}
			if ( $(".submitbox").hasClass('ing') ) return;
			if ( self.hasClass('success') ) return;
			jQuery.ajax({
				url: "<?php echo admin_url('admin-ajax.php'); ?>",
				type: "POST",
				data: {'action': 'blueria_code', 'code': code},
				beforeSend: function() {
					$(".submitbox").addClass('ing');
				},
				success: function(result, stat) {
					if ( 'success' != stat ) return false;
					if ( 0 == result ) return false;
					$(".submitbox").removeClass('ing');
					if (result == 'yes') {
						self.addClass('success').removeClass('err').attr({readOnly: true});
						$("img.code").attr('onclick', '');
						$(".submitbox .submit").removeClass("disabled");
						toastr['success']('验证码正确');
					} else {
						self.removeClass('success').addClass('err').focus();
						toastr['error']('验证码有误，请重新输入！');
					}
				}
			});
		});

		//表单提交验证
		$("form").submit(function(){
			var title = $.trim( $("#title").val() );
			if ( '' == title ) {
				toastr['error']('标题不能留空');
				$("#title").focus();
				return false;
			}
			var content = $.trim( $("#content").val() );
			if ( '' == content ) {
				var vdo_url = $("input[name='video_url']");
				var img_url = $("input[name='image_url']");
				var img_up = $("#upload_image");
				if ( (vdo_url.length == 0 || vdo_url.val() == '') && (img_url.length == 0 || img_url.val() == '') && img_up.val() == '' ) {
					toastr['error']('如果你没有添加任何视频或图片 那么内容不能留空');
					$("#content").focus();
					return false;
				} else if ( vdo_url.length ) {	//验证视频地址合法性
					if ( ! /^http:\/\//.test( $.trim(vdo_url.val()) ) ) {
						toastr['error']('视频地址有误 请更正');
						vdo_url.focus();
						return false;
					}
				} else if ( img_url.length ) {	//验证图片地址合法性
					if ( ! /^http:\/\//.test( $.trim(img_url.val()) ) ) {
						toastr['error']('图片地址有误 请更正');
						img_url.focus();
						return false;
					}
				}
			}
			if ( $("input[name='tags[]']").length < 1 ) {
				toastr['info']('至少要选择一个标签');
				return false;
			}
			var code = $.trim( $("#code").val() );
			if ( '' == code ) {
				toastr['error']('请输入验证码');
				$("#code").focus();
				return false;
			}
			$(".submitbox").addClass('ing');
			// return false;
		});
	});
</script>

<?php get_footer(); ?>